/*
 * Copyright (C) 2013, 2014 Giorgio Vazzana
 *
 * This file is part of Seren.
 *
 * Seren is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Seren is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef NC_H
#define NC_H

#include "config.h"
#include <stddef.h>
#include <time.h>

#if defined(HAVE_NCURSESW_NCURSES_H)
#include <ncursesw/ncurses.h>
#elif defined(HAVE_NCURSES_H)
#include <ncurses.h>
#endif

/* ncurses context */
#define LBS 1024
struct NContext {
	int                  initialized;
	int                  rows, cols;
	/* windows */
	WINDOW              *win_title;
	WINDOW              *win_message;
	WINDOW              *win_nodelist;
	WINDOW              *win_status;
	WINDOW              *win_input;
	/* keyboard input */
	char                 linebuf[LBS*4];
	size_t               linepos;
	unsigned char        wlinebuf[LBS][4];
	size_t               wlinepos;
};

extern struct NContext   nctx;

int  nc_init(const char *version, const char *nick, int theme);
int  nc_resize(const char *version, const char *nick);
void nc_close(void);
void nc_print_bars(const char *version);
void nc_clear_input_line_and_print_prompt(const char *nick, int delete_buffer);
int  nc_scroll_input_text(const char *nick, size_t right_space);
void nc_status(int micmute, int record, int mode, float peak_percent, double dBSPL,
               const char *timer_str, const char *stat_str);
void nc_nodelist(unsigned int n, const char *nicks[], int mute[], double dBSPL[],
                 unsigned int pl10k[], unsigned int tm_pl10k[]);

void nc_print_cb(time_t ts, unsigned int type, const char *module, const char *msg);

#endif
